# bnfinder
BNFinder - tool for learning bayesian networks.

It can be used for both dynamic and static networks. It is written in python (requires version >= 3.8), and distributed under GNU GPL Library version 2.

The installation is performed by a single command in the source directory (it may require the administrator privileges):

`python setup.py install`

Or install from PyPI:

`pip install BNfinder`

During the installation it will automaticaly setup scipy python packages if needed. Also you can run it without installing:

`python bnf --help`

You can also refer to previous version:

http://bioputer.mimuw.edu.pl/software/bnf/

Latest docs are in the `doc` folder of the repo. Here is the article describing latest version of BNFinder:

Frolova A, Wilczyński B. (2018) Distributed Bayesian networks reconstruction on the whole genome scale. PeerJ 6:e5692 https://doi.org/10.7717/peerj.5692
